function [Me,Ke] = ElementMatrices(nodcoor,subm,crack,E,rho,A,I,D)
% ElementMatrices Establishes element stiffness and mass matrix
%   nodcoor: Nodal coordinates [2x2 matrix]
%   E: Young's modulus (assumed constant over length)
%   A: Cross-section area (assumed constant over length)
%   I: Area moment of inertia (assumed constant over length)
%   rho: Material density (assumed constant over length)

global Kc

% Local coordinates
x1 = nodcoor(1,1);
x2 = nodcoor(2,1);
z1 = nodcoor(1,2);
z2 = nodcoor(2,2);
  
L = sqrt((x2-x1)^2+(z2-z1)^2);      % Length [m]

% Stiffness and mass matrix
if ~crack                           % Element cracked?
    Kr = 0;
else
    Kr = Kc;
end

% Stiffness matrix with crack
a = A/(I*L);
b = 3*Kr^2+6*Kr*L+4*L^2;
c = 3*Kr^2+6*Kr*L+2*L^2;
Ke_loc = E*I*[ a       0              0  -a        0               0;    
               0  12/L^3          6/L^2   0  -12/L^3           6/L^2;
               0   6/L^2  b/(L*(Kr+L)^2)  0   -6/L^2  c/(L*(Kr+L)^2);
              -a       0              0   a        0               0;
               0 -12/L^3         -6/L^2   0   12/L^3          -6/L^2;
               0   6/L^2  c/(L*(Kr+L)^2)  0   -6/L^2  b/(L*(Kr+L)^2)];
               
%     a = A*L^2/I;
%     Ke_loc = E*I/L^3*[ a    0      0  -a     0      0;      % Stiffness matrix
%                        0   12    6*L   0   -12    6*L; 
%                        0  6*L  4*L^2   0  -6*L  2*L^2; 
%                       -a    0      0   a     0      0;
%                        0  -12   -6*L   0    12   -6*L;
%                        0  6*L  2*L^2   0  -6*L  4*L^2];


% Body mass matrix
Mbe_loc = rho*A*L/420*[140      0       0   70      0       0;  
                         0    156    22*L    0     54   -13*L;
                         0   22*L   4*L^2    0   13*L  -3*L^2;
                        70      0       0  140      0       0;
                         0     54    13*L    0    156   -22*L;
                         0  -13*L  -3*L^2    0  -22*L   4*L^2];

% Added mass matrix
if subm                     % Element submerged?
    rho_w = 1025;           % Density of sea water [kg/m3]
    Cm = 1.6;               % Inertia coefficient (see also Morison equation)
    Ca = Cm-1;              % Added mass coefficient
    V_d = pi*D^2/4*L;       % Displaced volume [m3]
                     
    Mae_loc = rho_w*Ca*V_d/420*[140      0       0   70      0       0; 
                                  0    156    22*L    0     54   -13*L;
                                  0   22*L   4*L^2    0   13*L  -3*L^2;
                                 70      0       0  140      0       0;
                                  0     54    13*L    0    156   -22*L;
                                  0  -13*L  -3*L^2    0  -22*L   4*L^2];
                              
else
    Mae_loc = 0;
end
                          
Me_loc = Mbe_loc + Mae_loc;     % Total mass matrix

% Transformation to global coordinate system
c = (x2-x1)/L;
s = (z2-z1)/L;

T = [c  s  0  0  0  0;
    -s  c  0  0  0  0;
     0  0  1  0  0  0;
     0  0  0  c  s  0;
     0  0  0 -s  c  0;
     0  0  0  0  0  1];

Ke = T.'*Ke_loc*T;
Me = T.'*Me_loc*T;

