function f_hydro = Hydro_Morison_irr_lin(t)
% Calculates force vector
%   t: Time [s]

global f zeta omega k phase_JS u_c Cm Cd d nodcoor elemnod elemD elemSubm

rho_w = 1025;                           % Density of sea water [kg/m3]

% Automatic sizing of y vector
aa = size(nodcoor,1)*3;
fi = zeros(aa,1);
fd = zeros(aa,1);

nelem = size(elemnod,1);    % Number of elements
for j = 1:nelem             % Loop over all elements
    
    % Global coordinates
    nod1 = elemnod(j,1);    
    nod2 = elemnod(j,2);
    eft = [3*nod1-2, 3*nod1-1, 3*nod1, 3*nod2-2, 3*nod2-1, 3*nod2];
    
    if elemSubm(j)
    
        % Local coordinates
        elemnodcoor = [nodcoor(nod1,:); nodcoor(nod2,:)];
        x1 = elemnodcoor(1,1); 
        x2 = elemnodcoor(2,1);
        z1 = elemnodcoor(1,2);
        z2 = elemnodcoor(2,2);

        % Wave velocities and accelerations
        u_x1 = 0;
        u_z1 = 0;
        u_x2 = 0;
        u_z2 = 0;
        a_x1 = 0;
        a_z1 = 0;
        a_x2 = 0;
        a_z2 = 0;
        
        for l = 1:length(f)
            u_x1 = u_x1 + omega(l)*zeta(l)*cosh(k(l)*z1)/sinh(k(l)*d)...
                          *sin(omega(l)*t-k(l)*x1+phase_JS(l));
            u_z1 = u_z1 + omega(l)*zeta(l)*sinh(k(l)*z1)/sinh(k(l)*d)...
                          *cos(omega(l)*t-k(l)*x1+phase_JS(l));
            u_x2 = u_x2 + omega(l)*zeta(l)*cosh(k(l)*z2)/sinh(k(l)*d)...
                          *sin(omega(l)*t-k(l)*x2+phase_JS(l));
            u_z2 = u_z2 + omega(l)*zeta(l)*sinh(k(l)*z2)/sinh(k(l)*d)...
                          *cos(omega(l)*t-k(l)*x2+phase_JS(l));
            a_x1 = a_x1 + omega(l)^2*zeta(l)*cosh(k(l)*z1)/sinh(k(l)*d)...
                          *cos(omega(l)*t-k(l)*x1+phase_JS(l));
            a_z1 = a_z1 - omega(l)^2*zeta(l)*sinh(k(l)*z1)/sinh(k(l)*d)...
                          *sin(omega(l)*t-k(l)*x1+phase_JS(l));
            a_x2 = a_x2 + omega(l)^2*zeta(l)*cosh(k(l)*z2)/sinh(k(l)*d)...
                          *cos(omega(l)*t-k(l)*x2+phase_JS(l));
            a_z2 = a_z2 - omega(l)^2*zeta(l)*sinh(k(l)*z2)/sinh(k(l)*d)...
                          *sin(omega(l)*t-k(l)*x2+phase_JS(l));
        end
        
        % Member's properties
        D = elemD(j);                       % Member's diameter [m]
        A = 1/4*pi*D^2;                     % Member's cross-section area [m^2]
        L = sqrt((x2-x1)^2+(z2-z1)^2);      % Member's length

        c = (x2-x1)/L; % cos(phi)
        s = (z2-z1)/L; % sin(phi)

        T = [c  s  0  0  0  0;      % Transformation matrix
            -s  c  0  0  0  0;
             0  0  1  0  0  0;
             0  0  0  c  s  0;
             0  0  0 -s  c  0;
             0  0  0  0  0  1];
         
        
        % Inertia force term
        fi1 = rho_w*Cm*A*(a_x1*s+a_z1*c);
        fi2 = rho_w*Cm*A*(a_x2*s+a_z2*c);

        % Integration of linear wave force distribution from 0 to L 
        fi_1 = 1/20*(13*fi1-3*fi2)*L;
        fi_2 = 1/60*(7*fi1-2*fi2)*L^2;
        fi_3 = 1/20*(17*fi1-7*fi2)*L;
        fi_4 = 1/60*(-8*fi1+3*fi2)*L^2;

        fie = [0;fi_1;fi_2;0;fi_3;fi_4];

        fie = T.'*fie;      % Tranformation

        % Drag force term
        fd1 = 0.5*rho_w*Cd*D * (u_x1*s+u_z1*c+u_c*s) * abs(u_x1*s+u_z1*c+u_c*s);
        fd2 = 0.5*rho_w*Cd*D * (u_x2*s+u_z2*c+u_c*s) * abs(u_x2*s+u_z2*c+u_c*s);

        % Integration of linear wave force distribution
        fd_1 = 1/20*(13*fd1-3*fd2)*L;
        fd_2 = 1/60*(7*fd1-2*fd2)*L^2;
        fd_3 = 1/20*(17*fd1-7*fd2)*L;
        fd_4 = 1/60*(-8*fd1+3*fd2)*L^2;

        fde = [0;fd_1;fd_2;0;fd_3;fd_4];

        fde = T.'*fde;      % Tranformation
        
    else
         
       fie = zeros(6,1);
       fde = zeros(6,1);
       
    end
    
    % Assembly to global force vector
    for m = 1:6
        mm = eft(m);
        fi(mm) = fi(mm)+fie(m);
        fd(mm) = fd(mm)+fde(m);
    end 
    
end

% Total global force vector
f_hydro = fi+fd;
