function f_wind = Wind_Morison_lin(t)
% Calculates force vector
%   t: Time [s]

global f_wi df_wi phase_list V_hub sigma1 d nodcoor elemnod elemD elemWind

rho_w = 1.225;   % Density of air [kg/m3]
Cd = 0.8;        % Drag coefficient
  
% Automatic sizing of y vector
aa = size(nodcoor,1)*3;
fd = zeros(aa,1);
counter = 0;

nelem = size(elemnod,1);    % Number of elements
for i = 1:nelem             % Loop over all elements
    
    % Global coordinates
    nod1 = elemnod(i,1);
    nod2 = elemnod(i,2);
    eft = [3*nod1-2, 3*nod1-1, 3*nod1, 3*nod2-2, 3*nod2-1, 3*nod2];
    
    if elemWind(i)
        counter = counter+1;
        phase_KM = phase_list(counter,:);
        
        % Local coordinates
        elemnodcoor = [nodcoor(nod1,:); nodcoor(nod2,:)];
        x1 = elemnodcoor(1,1); 
        x2 = elemnodcoor(2,1);
        z1 = elemnodcoor(1,2);
        z2 = elemnodcoor(2,2);
        
        nod_hub = elemnod(end,2);   % Assuming hub has always highest node number
        z_hub = nodcoor(nod_hub,2);
             
        S_KM1 = zeros(length(f_wi),1);
        S_KM2 = zeros(length(f_wi),1);
        amp_wi1 = zeros(length(f_wi),1);
        amp_wi2 = zeros(length(f_wi),1);
        omega_wi = zeros(length(f_wi),1);
        V_var1 = 0;
        V_var2 = 0;
        
        alpha = 0.2;
        V_mean1 = V_hub*((z1-d)/(z_hub-d))^alpha;  % Mean wind speed at node 1
        V_mean2 = V_hub*((z2-d)/(z_hub-d))^alpha;  % Mean wind speed at node 2
        I1 = sigma1/V_mean1;
        I2 = sigma1/V_mean2;
        
        if z1-d < 60
            Lk1 = 5.67*(z_hub-d);            % Integral scale parameter Lk1
        else
            Lk1 = 8.1*42;
        end
        
        if z2-d < 60
            Lk2 = 5.67*(z_hub-d);            % Integral scale parameter Lk2
        else
            Lk2 = 8.1*42;
        end

        for k = 1:length(f_wi)
            % Kaimal spectrum node 1
            S_KM1(k) = 4*I1^2*V_mean1*Lk1/((1+6*f_wi(k)*Lk1/V_mean1)^(5/3)); 
            % Kaimal spectrum node 2
            S_KM2(k) = 4*I2^2*V_mean2*Lk2/((1+6*f_wi(k)*Lk2/V_mean2)^(5/3)); 
            amp_wi1(k) = sqrt(2*S_KM1(k)*df_wi);      % Wind amplitude [m/s]
            amp_wi2(k) = sqrt(2*S_KM2(k)*df_wi);
            omega_wi(k) = 2*pi*f_wi(k);               % Wind frequency [rad/s]
            V_var1 = V_var1 + amp_wi1(k)*sin(omega_wi(k)*t+phase_KM(k));
            V_var2 = V_var2 + amp_wi2(k)*sin(omega_wi(k)*t+phase_KM(k));
        end
        
        % Member's properties
        D = elemD(i);                       % Member's diameter [m]
        L = sqrt((x2-x1)^2+(z2-z1)^2);      % Member's length

        c = (x2-x1)/L; % cos(phi)
        s = (z2-z1)/L; % sin(phi)

        T = [c  s  0  0  0  0;      % Transformation matrix
            -s  c  0  0  0  0;
             0  0  1  0  0  0;
             0  0  0  c  s  0;
             0  0  0 -s  c  0;
             0  0  0  0  0  1];
         
        % Drag force term
        fd1 = 0.5*rho_w*Cd*D * ((V_mean1+V_var1)*s) * abs((V_mean1+V_var1)*s);
        fd2 = 0.5*rho_w*Cd*D * ((V_mean2+V_var2)*s) * abs((V_mean2+V_var2)*s); 

        % Integration of linear wave force distribution
        fd_1 = 1/20*(13*fd1-3*fd2)*L;
        fd_2 = 1/60*(7*fd1-2*fd2)*L^2;
        fd_3 = 1/20*(17*fd1-7*fd2)*L;
        fd_4 = 1/60*(-8*fd1+3*fd2)*L^2;

        fde = [0;fd_1;fd_2;0;fd_3;fd_4];

        fde = T.'*fde;      % Tranformation
        
    else              
        fde = zeros(6,1);
    end
    
    % Assembly to global force vector
    for m = 1:6
        mm = eft(m);
        fd(mm) = fd(mm)+fde(m);
    end 
end

% 'Thrust' force
eft_hub = [3*nod_hub-2, 3*nod_hub-1, 3*nod_hub];
I = sigma1/V_hub;
if z_hub-d < 60
    Lk = 5.67*(z_hub-d);            % Integral scale parameter Lk1
else
    Lk = 8.1*42;
end

V_var_hub = 0;
S_KM = zeros(length(omega_wi),1);
amp_wi = zeros(length(omega_wi),1);
for p = 1:length(omega_wi)
    S_KM(p) = 4*I^2*V_hub*Lk/((1+6*f_wi(p)*Lk/V_hub)^(5/3));
    amp_wi(p) = sqrt(2*S_KM(p)*df_wi);
    V_var_hub = V_var_hub + amp_wi(p)*sin(omega_wi(p)*t+phase_KM(p));
end

V_thr = V_hub + V_var_hub;          % Same as V

% 'Rotor' properties
Cd_hub = 0.1;                % Higher drag coefficient to account for rotor
D_rot = 126;                  % Rotor diameter [m]
A_rot = pi*D_rot^2/4;         % Rotor area [m2]

% Drag force term
fd_hub = 0.5*rho_w*Cd_hub*A_rot*V_thr * abs(V_thr);      % Local

% Total global force vector
f_wind = fd;
f_wind(eft_hub(1)) = f_wind(eft_hub(1)) + fd_hub;


