% Generate the discrete-time state space model and determine the filtered 
% data by means of the Kalman filter

clear all
close all
clc

% Crack 'number'
cn = 8;                 % 1 to 8
cn_str = num2str(cn-1);

% 1) Generate and load the data and add noise
% dir = ['W:\Master Thesis\UpWind Jacket\Response\Results\Jacket 1\Cracked ' cn_str '\1Hz'];
dir = ['W:\Master Thesis\UpWind Jacket\Response\Results\Jacket 1\Cracked ' cn_str '\harmonic'];
% dir = ['W:\Master Thesis\UpWind Jacket\Response\Results\Jacket 1\Cracked ' cn_str '\10Hz'];

cd(dir);
load('eom.mat')
load('state.mat')
load('a_k.mat')         
load('t.mat')           % Time/sample vector [N x 1]
load('p.mat')           % Force matrix [nDOF x N]

A = state.A;            % System matrix A
B = state.B;            % Input matrix B

dt = t(2)-t(1);         % Sample size/time step
nDOF = size(A,1)/2;     % Number of degrees of freedom
N = size(t,2);          % Number of samples
n_p = nDOF;             % Number of forces
n_d = 3;                % Number of observations


% 2) Create observation/measurement data
% Selection matrices
S_d = zeros(n_d,nDOF);      % Velocity
S_v = zeros(n_d,nDOF);      % Displacements
S_p = eye(nDOF);            % Forces
S_a = zeros(n_d,nDOF);      % Selection matrix for accelerations

a = a_k;                    % Acceleration matrix [nDOF x N]
loc = [70 79 91];           % Degrees of freedom where measured [a1 a2 ...]
S_a(1,loc(1)) = 1;
S_a(2,loc(2)) = 1;
S_a(3,loc(3)) = 1;
d = S_a*a;                  % Observation matrix [n_d x N]

% Add measurement noise
nl = 0.1;                  % Noise level
noise = zeros(n_d,N);
d_n = zeros(n_d,N);
for ind = 1:n_d
	noise(ind,:) = nl*std(d(ind,:))*randn(1,N);
    d_n(ind,:) = d(ind,:) + noise(ind,:);
end


% 3) Construct the (discrete-time) state-space matrices A, B, C and D
Mi = eom.Mi;                        % Inverse mass matrix [nDOF x nDOF]
C = eom.C;                          % Damping matrix [nDOF x nDOF]
K = eom.K;                          % Stiffness matrix [nDOF x nDOF]

G = [S_d-S_a*Mi*K S_v-S_a*Mi*C];    % Output matrix G [n_d x 2nDOF]
J = S_a*Mi*S_p;                     % Direct transmission matrix J [n_d x nDOF]


% 4) State estimation
Q = 1e-5*eye(nDOF*2);               % Process noise covariance matrix
R = 0.1*diag(std(noise,0,2));       % Measurement noise covariance matrix
x0 = zeros(nDOF*2,1);               % Initial state estimate
P0 = 1e-3*eye(nDOF*2);              % Initial state error covariance matrix

[x_id,P_id] = kalman_filter(A,B,G,J,Q,R,P0,x0,p,d_n);   % x_id [2nDOF x N]


% 5) Response prediction
n_d = nDOF;                   % Number of output positions
% Displacements
S_d1 = eye(n_d,nDOF);
S_v1 = zeros(n_d,nDOF);
S_a1 = zeros(n_d,nDOF);
G1 = [S_d1-S_a1*Mi*K S_v1-S_a1*Mi*C];
J1 = S_a1*Mi*S_p;
u_pr = G1*x_id+J1*p;          % Predicted displacements [n_d x N], here [nDOF x N]

% Velocities
S_d2 = zeros(n_d,nDOF);
S_v2 = eye(n_d,nDOF);
S_a2 = zeros(n_d,nDOF);
G2 = [S_d2-S_a2*Mi*K S_v2-S_a2*Mi*C];
J2 = S_a2*Mi*S_p;
v_pr = G2*x_id+J2*p;          % Predicted velocities [n_d x N], here [nDOF x N]

% Accelerations
S_d3 = zeros(n_d,nDOF);
S_v3 = zeros(n_d,nDOF);
S_a3 = eye(n_d,nDOF);
G3 = [S_d3-S_a3*Mi*K S_v3-S_a3*Mi*C];
J3 = S_a3*Mi*S_p;
a_pr = G3*x_id+J3*p;          % Predicted accelerations [n_d x N], here [nDOF x N]

% Save
% dir = ['W:\Master Thesis\UpWind Jacket\Kalman filter\Results\Jacket 1\Cracked ' cn_str '\1Hz'];
dir = ['W:\Master Thesis\UpWind Jacket\Kalman filter\Results\Jacket 1\Cracked ' cn_str '\harmonic'];
% dir = ['W:\Master Thesis\UpWind Jacket\Kalman filter\Results\Jacket 1\Cracked ' cn_str '\10Hz'];

cd(dir);
save('u_pr.mat','u_pr')
save('v_pr.mat','v_pr')
save('a_pr.mat','a_pr')
save('t.mat','t')
% save('P_id.mat','P_id')


